@@ -568,6 +568,8 @@ def register():
     logDIR = args.logdir
     if logDIR is None:
         logDIR = Path.cwd() / args.jobname
+    elif Path(logDIR) == Path('./'):
+        logDIR = Path.cwd()
     else:
         logDIR = Path(logDIR) / args.jobname
 
